// this is a very basic template. use it to start writing your own effects.
// if you want effects with lighting start from one of the GouraudXXXX or PhongXXXX effects

// --------------------------------------------------------------------------------------------------
// PARAMETERS:
// --------------------------------------------------------------------------------------------------

//transforms
float4x4 tW: WORLD;        //the models world matrix
float4x4 tV: VIEW;         //view matrix as set via Renderer (EX9)
float4x4 tP: PROJECTION;
float4x4 tWVP: WORLDVIEWPROJECTION;

//textures

texture Tex1px <string uiname="Texture 1px";>;
sampler Samp1px = sampler_state    //sampler for doing the texture-lookup
{
    Texture   = (Tex1px);          //apply a texture to the sampler
    MipFilter = LINEAR;         //sampler states
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};

texture Tex <string uiname="Texture";>;
sampler Samp = sampler_state    //sampler for doing the texture-lookup
{
    Texture   = (Tex);          //apply a texture to the sampler
    MipFilter = LINEAR;         //sampler states
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};

int Width: POSITION <string uiname="Width";>;
int Height: POSITION <string uiname="Height";>;

//texture transformation marked with semantic TEXTUREMATRIX to achieve symmetric transformations
float4x4 tTex: TEXTUREMATRIX <string uiname="Texture Transform";>;

//the data structure: "vertexshader to pixelshader"
//used as output data with the VS function
//and as input data with the PS function

struct vs2ps
{
    float4 Pos  : POSITION;
    float2 TexCd : TEXCOORD0;
};

// --------------------------------------------------------------------------------------------------
// VERTEXSHADERS
// --------------------------------------------------------------------------------------------------
vs2ps VS(
    float4 PosO  : POSITION,
    float4 TexCd : TEXCOORD0)
{
    //declare output struct
    vs2ps Out;

    //transform position
    Out.Pos = mul(PosO, tWVP);
    
    //transform texturecoordinates
    Out.TexCd = mul(TexCd, tTex);
    return Out;
}

// --------------------------------------------------------------------------------------------------
// PIXELSHADERS:
// --------------------------------------------------------------------------------------------------

float4 MinMaxAlpha(vs2ps In): COLOR
{
    int y_offset=Height/2;
    //The video has 2 parts : 1 with the colors (y:0->Height/2,
    //the other in black&white (y:Height/2->Height) representing the alpha channel.
    //Due to the compression of the video, "alpha" doesn't go anymore from 0 to 1,
    //so I need to remap it. That's why I need Min and Max.

    float2 myTexCd;
    float4 col;
    float  alpha;
    
    float Min_Alpha=1;
    float Max_Alpha=0;

    /*
    for(int x=0;x<Width;++x)
    {
      for(int y=0;y<y_offset;++y)
      {
        myTexCd = (In.TexCd.x, In.TexCd.y);
        col = tex2D(Samp, myTexCd);
        alpha=(col.r + col.g + col.b)/3;
        Min_Alpha=min(Min_Alpha,alpha);
        Max_Alpha=max(Max_Alpha,alpha);
      }
    }
    */
    
    col=(Min_Alpha,Max_Alpha,1,1);
    //col=(1,1,1,1);

    return col;
}


// --------------------------------------------------------------------------------------------------
// TECHNIQUES:
// --------------------------------------------------------------------------------------------------

technique MinMaxAlpha
{
    pass P0
    {
        //Wrap0 = U;  // useful when mesh is round like a sphere
        VertexShader = compile vs_1_1 VS();
        PixelShader  = compile ps_2_b MinMaxAlpha();
    }
    
}
